==> fans-common-core-1.0.5-sources.jar: com/ptteng/sca/fans/common/client/UserMessageRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.UserMessageRelation;
import com.ptteng.fans.common.service.UserMessageRelationService;

import java.util.List;
import java.util.Map;

public class UserMessageRelationSCAClient implements UserMessageRelationService {

    private UserMessageRelationService userMessageRelationService;

	public UserMessageRelationService getUserMessageRelationService() {
		return userMessageRelationService;
	}
	
	
	public void setUserMessageRelationService(UserMessageRelationService userMessageRelationService) {
		this.userMessageRelationService =userMessageRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserMessageRelation userMessageRelation)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.insert(userMessageRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessageRelation> insertList(List<UserMessageRelation> userMessageRelationList)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.insertList(userMessageRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserMessageRelation userMessageRelation)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.update(userMessageRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserMessageRelation> userMessageRelationList)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.updateList(userMessageRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserMessageRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessageRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageRelationIdsByNameAndNick(Long targetId,Long userId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getUserMessageRelationIdsByNameAndNick(targetId,userId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageRelationIdsByNick(Long userId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getUserMessageRelationIdsByNick(userId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageRelationIdsByName(Long targetId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getUserMessageRelationIdsByName(targetId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageRelationIdsByNameAndNick(Long targetId,Long userId)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.countUserMessageRelationIdsByNameAndNick(targetId,userId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageRelationIdsByNick(Long userId)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.countUserMessageRelationIdsByNick(userId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageRelationIdsByName(Long targetId)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.countUserMessageRelationIdsByName(targetId);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserMessageRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.getUserMessageRelationIds(start, limit);
	}

	@Override
	public Integer countUserMessageRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.countUserMessageRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userMessageRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userMessageRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> fans-common-core-1.1.4-sources.jar: com/ptteng/sca/fans/common/client/UserMessageRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.UserMessageRelation;
import com.ptteng.fans.common.service.UserMessageRelationService;

import java.util.List;
import java.util.Map;

public class UserMessageRelationSCAClient implements UserMessageRelationService {

    private UserMessageRelationService userMessageRelationService;

	public UserMessageRelationService getUserMessageRelationService() {
		return userMessageRelationService;
	}
	
	
	public void setUserMessageRelationService(UserMessageRelationService userMessageRelationService) {
		this.userMessageRelationService =userMessageRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserMessageRelation userMessageRelation)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.insert(userMessageRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessageRelation> insertList(List<UserMessageRelation> userMessageRelationList)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.insertList(userMessageRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserMessageRelation userMessageRelation)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.update(userMessageRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserMessageRelation> userMessageRelationList)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.updateList(userMessageRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserMessageRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessageRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageRelationIdsByNameAndNick(Long targetId,Long userId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getUserMessageRelationIdsByNameAndNick(targetId,userId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageRelationIdsByNick(Long userId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getUserMessageRelationIdsByNick(userId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageRelationIdsByName(Long targetId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.getUserMessageRelationIdsByName(targetId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageRelationIdsByNameAndNick(Long targetId,Long userId)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.countUserMessageRelationIdsByNameAndNick(targetId,userId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageRelationIdsByNick(Long userId)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.countUserMessageRelationIdsByNick(userId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageRelationIdsByName(Long targetId)throws ServiceException, ServiceDaoException{
		
		return userMessageRelationService.countUserMessageRelationIdsByName(targetId);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserMessageRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.getUserMessageRelationIds(start, limit);
	}

	@Override
	public Integer countUserMessageRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.countUserMessageRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userMessageRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userMessageRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

    @Override
    public Object getMapListByDynamicCondition(Class clz,Map<String, Object> conditions, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return this.userMessageRelationService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}
